@@ -1,7 +1,7 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2009 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2009-2011 -- leonerd@leonerd.org.uk
 
 package Tickit::Widget::HBox;
 
@@ -9,7 +9,7 @@ use strict;
 use warnings;
 use base qw( Tickit::Widget::LinearBox );
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 use List::Util qw( sum max );
 
@@ -17,6 +17,35 @@ use List::Util qw( sum max );
 
 C<Tickit::Widget::HBox> - distribute child widgets in a horizontal row
 
+=head1 SYNOPSIS
+
+ use Tickit;
+ use Tickit::Widget::HBox;
+ use Tickit::Widget::Static;
+ use IO::Async::Loop;
+ 
+ my $loop = IO::Async::Loop->new;
+ 
+ my $tickit = Tickit->new;
+ $loop->add( $tickit );
+ 
+ my $hbox = Tickit::Widget::HBox->new;
+
+ foreach my $position (qw( left centre right )) {
+    $hbox->add(
+       Tickit::Widget::Static->new(
+          text   => $position,
+          align  => $position,
+          valign => "middle",
+       ),
+       expand => 1
+    );
+ }
+ 
+ $tickit->set_root_widget( $hbox );
+ 
+ $tickit->run;
+
 =head1 DESCRIPTION
 
 This container widget distributes its children in a horizontal row.
